@@ -23,12 +23,22 @@ class LivySparkConfig(SparkEngineConfig):
 
     ignore_ssl_errors = parameter(description="ignore ssl error", default=False)[bool]
 
-    post_submit_hook = parameter(
+    job_submitted_hook = parameter(
         description="User code to run after livy batch submit (a reference to a function)"
         "expected interface (LivySparkCtrl, Dict[str, Any]) -> None",
         default=None,
     )[str]
 
+    job_status_hook = parameter(
+        description="User code to run at each livy batch status update (a reference to a function)"
+        "expected interface (LivySparkCtrl, Dict[str, Any]) -> None",
+        default=None,
+    )[str]
+
+    retry_on_status_error = parameter(
+        description="retries http requests if status code is not accepted", default=0
+    )[int]
+
     def get_spark_ctrl(self, task_run):
         from dbnd_spark.livy.livy_spark import LivySparkCtrl
 
